@@ -19,11 +19,15 @@
  *
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
+#include <glib/gi18n.h>
+
 #include "gs-theme-window.h"
 #include "gs-theme-engine.h"
 #include "gste-popsquares.h"
@@ -35,13 +39,9 @@ main (int argc, char **argv)
         GtkWidget     *window;
         GError        *error;
 
-#ifdef ENABLE_NLS
         bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-# ifdef HAVE_BIND_TEXTDOMAIN_CODESET
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-# endif 
         textdomain (GETTEXT_PACKAGE);
-#endif 
 
         error = NULL;
 
